import { CommaSeparatedStringArray } from '@n8n/config';
export declare const MODULE_NAMES: readonly ["insights", "external-secrets"];
export type ModuleName = (typeof MODULE_NAMES)[number];
declare class ModuleArray extends CommaSeparatedStringArray<ModuleName> {
    constructor(str: string);
}
export declare class ModulesConfig {
    enabledModules: ModuleArray;
    disabledModules: ModuleArray;
}
export {};
